@@ -5,7 +5,7 @@ use Number::Phone::Country::Data;
 
 # *_codes are global so we can mock in some tests
 use vars qw($VERSION %idd_codes %prefix_codes);
-$VERSION = 1.97;
+$VERSION = 1.98;
 my $use_uk = 0;
 
 sub import {
@@ -32,22 +32,22 @@ sub phone2country {
 our %NANP_areas = (
     CA => do {
         # see http://www.cnac.ca/co_codes/co_code_status.htm
-        # checked on 2021-12-06
-        # next check due 2022-06-01 (semi-annually)
+        # checked on 2023-09-02
+        # next check due 2024-03-01 (semi-annually)
         my $canada = join('|', qw(
-            204 226 236 249 250 263 289
-            306 343 354 365 367 368
+            204 226 236 249 250 257 263 289
+            306 343 354 365 367 368 382
             403 416 418 428 431 437 438 450 468 474
-            506 514 519 548 579 581 587
+            506 514 519 548 579 581 584 587
             604 613 639 647 672 683
             705 709 742 753 778 780 782
             807 819 825 867 873 879
-            902 905
+            902 905 942
         ));
         # handful of non-geographic country-specific codes ...
         # see https://en.wikipedia.org/wiki/Area_code_600
-        # checked on 2021-12-06
-        # next check due 2022-06-01 (semi-annually)
+        # checked on 2023-09-02
+        # next check due 2024-09-01 (annually)
         $canada = join('|', $canada, 600, 622, 633, 644, 655, 677, 688);
     },
     US => do {
@@ -56,70 +56,70 @@ our %NANP_areas = (
         #   but the latter doesn't contain some overlays that are about to come into service
         # NB for Hyder, Alaska, it shares three COs with Stewart, BC, and we can't tell which number is in which country,
         #   so those prefixes aren't listed here
-        # checked on 2021-12-06
-        # next check due 2022-06-01 (semi-annually)
+        # checked on 2023-09-02
+        # next check due 2024-03-01 (semi-annually)
         my $usa = join('|', qw(
             205 251 256 334 659 938
             907
             480 520 602 623 928
             327 479 501 870
-            209 213 279 310 323 341 408 415 424 442 510 530 559 562 619 626 628 650 657 661 669 707 714 747 760 805 818 820 831 840 858 909 916 925 949 951
+            209 213 279 310 323 341 350 369 408 415 424 442 510 530 559 562 619 626 628 650 657 661 669 707 714 747 760 805 818 820 831 840 858 909 916 925 949 951
             303 719 720 970 983
             203 475 860 959
             302
             202 771
-            239 305 321 352 386 407 448 561 656 689 727 754 772 786 813 850 863 904 941 954
+            239 305 321 324 352 386 407 448 561 645 656 689 727 728 754 772 786 813 850 863 904 941 954
             229 404 470 478 678 706 762 770 912 943
             808
             208 986
-            217 224 309 312 331 447 464 618 630 708 730 773 779 815 847 872
+            217 224 309 312 331 447 464 618 630 708 730 773 779 815 847 861 872
             219 260 317 463 574 765 812 930
             319 515 563 641 712
             316 620 785 913
             270 364 502 606 859
-            225 318 337 504 985
+            225 318 337 457 504 985
             207
             227 240 301 410 443 667
             339 351 413 508 617 774 781 857 978
             231 248 269 313 517 586 616 679 734 810 906 947 989
-            218 320 507 612 651 763 952
+            218 320 507 612 651 763 924 952
             228 601 662 769
-            314 417 557 573 636 660 816 975
+            235 314 417 557 573 636 660 816 975
             406
             308 402 531
             702 725 775
             603
             201 551 609 640 732 848 856 862 908 973
             505 575
-            212 315 332 347 516 518 585 607 631 646 680 716 718 838 845 914 917 929 934
-            252 336 704 743 828 910 919 980 984
+            212 315 329 332 347 363 516 518 585 607 624 631 646 680 716 718 838 845 914 917 929 934
+            252 336 472 704 743 828 910 919 980 984
             701
-            216 220 234 283 326 330 380 419 440 513 567 614 740 937
+            216 220 234 283 326 330 380 419 436 440 513 567 614 740 937
             405 539 572 580 918
             458 503 541 971
-            215 223 267 272 412 445 484 570 582 610 717 724 814 878
+            215 223 267 272 412 445 484 570 582 610 717 724 814 835 878
             401
-            803 839 843 854 864
+            803 821 839 843 854 864
             605
             423 615 629 731 865 901 931
             210 214 254 281 325 346 361 409 430 432 469 512 682 713 726 737 806 817 830 832 903 915 936 940 945 956 972 979
             385 435 801
             802
-            276 434 540 571 703 757 804 826 948
+            276 434 540 571 686 703 757 804 826 948
             206 253 360 425 509 564
             304 681
-            262 274 414 534 608 715 920
+            262 274 353 414 534 608 715 920
             307
         ));
         # handful of non-geographic country-specific codes ...
         # see https://en.wikipedia.org/wiki/Area_code_710
-        # checked on 2021-12-06
-        # next check due 2023-12-01 (bi-annually)
+        # checked on 2023-09-02
+        # next check due 2025-09-01 (bi-annually)
         $usa    = join('|', $usa, 710);
     },
     # see https://en.wikipedia.org/wiki/North_American_Numbering_Plan#Countries_and_territories
-    # checked on 2021-12-06
-    # next check due 2022-12-01 (annually)
+    # checked on 2023-12-10
+    # next check due 2024-12-01 (annually)
     AS => '684',         # American Samoa
     AI => '264',         # Anguilla
     AG => '268',         # Antigua and Barbude
@@ -196,7 +196,7 @@ sub phone2country_and_idd {
                     }
                     $country = @$country[0];
                 }
-
+                $country =~ s/.*:://;
                 return ($country, $idd);
             }
         }
@@ -205,7 +205,8 @@ sub phone2country_and_idd {
 }
 
 sub country_code {
-    my $country = uc shift;
+    my $country = shift;
+    $country    = uc($country) if($country =~ /^[a-z]{2}$/i);
 
     my $data = $prefix_codes{$country} or return;
 
@@ -406,7 +407,7 @@ Thanks to Shraga Bor-Sood for the updates in version 1.4.
 
 Copyright 2003 by MaxMind LLC
 
-Copyright 2004 - 2011 David Cantrell
+Copyright 2004 - 2023 David Cantrell
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
